@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-from .tea import TEA
+from ._tea import TEA, check_pymalloc
 from .pytea import TEA as PYTEA
 
-__version__ = "0.1.2"
+__version__ = "0.2.0"
 __author__ = "synodriver"
